@@ -1,6 +1,6 @@
 context("test-crime-at-location")
 
-test_that("multiplication works", {
+test_that("crime at location works works", {
   skip_on_cran()
   x <- ukc_crime_location(lat = 52, lng = 0)
   expect_true(length(x) == 9)
